"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const fs_1 = require("fs");
const path_1 = require("path");
const rimraf_1 = require("rimraf");
const chalk_1 = __importDefault(require("chalk"));
const pretty_ms_1 = __importDefault(require("pretty-ms"));
function pluginRemoteContent(context, options) {
    let { blogIntegration, docsIntegration, sourceBaseUrl, documents, noRuntimeDownloads, performCleanup, outputDirectory, } = options;
    if (![blogIntegration, docsIntegration].includes(true)) {
        throw new Error("No integrations enabled! Please enable either the blogIntegration or docsIntegration fields in your remote-content plugin options.");
    }
    if (blogIntegration === true && docsIntegration === true) {
        throw new Error("You can only have one integration enabled per plugin instance!");
    }
    if (!documents) {
        throw new Error("The documents field is undefined, so I don't know what to fetch!");
    }
    if (!sourceBaseUrl) {
        throw new Error("The sourceBaseUrl field is undefined, so I don't know where to fetch from!");
    }
    if (!sourceBaseUrl.endsWith("/")) {
        sourceBaseUrl = `${sourceBaseUrl}/`;
    }
    function findCollectables() {
        const a = [];
        if (docsIntegration === true || blogIntegration === true) {
            ;
            (typeof documents == "function"
                ? documents.call(context.siteConfig)
                : documents).forEach((d) => {
                if (d.endsWith("md")) {
                    a.push({ url: `${sourceBaseUrl}/${d}`, identifier: d });
                }
                else {
                    a.push({ url: `${sourceBaseUrl}/${d}.md`, identifier: `${d}.md` });
                }
            });
        }
        return a;
    }
    async function getTargetDirectory() {
        let returnValue = undefined;
        if (docsIntegration) {
            returnValue = (0, path_1.join)(context.siteDir, "docs");
        }
        if (blogIntegration) {
            returnValue = (0, path_1.join)(context.siteDir, "blog");
        }
        if (!returnValue) {
            throw new Error("Fell through! No integrations are enabled! Please check the documentation.");
        }
        if (outputDirectory) {
            returnValue = (0, path_1.join)(returnValue, outputDirectory);
        }
        if (!(0, fs_1.existsSync)(returnValue)) {
            (0, fs_1.mkdirSync)(returnValue);
        }
        return returnValue;
    }
    async function fetchContent() {
        const c = findCollectables();
        for (let i = 0; i < c.length; i++) {
            (0, fs_1.writeFileSync)((0, path_1.join)(await getTargetDirectory(), c[i].identifier), (await (0, axios_1.default)({ url: c[i].url })).data);
        }
    }
    async function cleanContent() {
        const c = findCollectables();
        for (let i = 0; i < c.length; i++) {
            (0, rimraf_1.sync)((0, path_1.join)(await getTargetDirectory(), c[i].identifier));
        }
    }
    return {
        name: `docusaurus-plugin-remote-content-${[blogIntegration && "blog", docsIntegration && "docs"].filter(Boolean)[0]}`,
        async loadContent() {
            if (!noRuntimeDownloads) {
                return await fetchContent();
            }
        },
        async postBuild() {
            if (performCleanup !== false) {
                return await cleanContent();
            }
        },
        extendCli(cli) {
            const t = [blogIntegration && "blog", docsIntegration && "docs"].filter(Boolean)[0];
            cli
                .command(`download-remote-${t}`)
                .description(`Downloads the remote ${t} data.`)
                .action(async () => {
                const startTime = new Date();
                await fetchContent();
                console.log((0, chalk_1.default) `{green Successfully fetched content in} {white ${(0, pretty_ms_1.default)(new Date() - startTime)}}{green !}`);
            });
            cli
                .command(`clear-remote-${t}`)
                .description(`Removes the local copy of the remote ${t} data.`)
                .action(async () => {
                const startTime = new Date();
                await cleanContent();
                console.log((0, chalk_1.default) `{green Successfully deleted content in} {white ${(0, pretty_ms_1.default)(new Date() - startTime)}}{green !}`);
            });
        },
    };
}
exports.default = pluginRemoteContent;
//# sourceMappingURL=index.js.map